<script setup>
import {$go} from '../../composables/goto';
</script>


<template>
    <AppLayout title="Projects">
        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight"> Projects
                <el-button text size="small" class="ml-4" rounded @click="$go(route('projects.create'))">
                    <el-icon class="el-icon--left">
                        <Plus/>
                    </el-icon>
                    Add Project
                </el-button>
            </h2>
        </template>
        <div>
            <div class="max-w-6xl mx-auto py-5 sm:px-2 mt-8 ">
                <el-empty description="No project exist yet." v-if="!projects.length">
                    <el-button @click="$go(route('projects.create'), {data: {}})" link class="uppercase" size="small"
                               type="primary">
                        <el-icon class="el-icon--left">
                            <Plus/>
                        </el-icon>
                        Add project
                    </el-button>
                </el-empty>
                <div v-else>
                    <el-table size="small" :data="projects" style="width: 100%">
                        <el-table-column label="#" width="25">
                            <template #default="scope">
                                {{ scope.$index + 1 }}
                            </template>
                        </el-table-column>
                        <el-table-column prop="name" label="Name">
                            <template #default="scope"><strong>{{ scope.row.name }}</strong></template>
                        </el-table-column>
                        <el-table-column prop="description" label="Description" show-overflow-tooltip/>
                        <el-table-column label="Status" width="80px" align="center">
                            <template #default="scope">
                                <el-tag effect="dark" :type="`${scope.row.active ? 'success':'warning'}`" size="small">
                                    {{ scope.row.active ? 'Active' : 'Inactive' }}
                                </el-tag>
                            </template>
                        </el-table-column>
                        <el-table-column prop="licenses_count" label="Licenses" align="center"/>
                        <el-table-column prop="user.name" label="Creator" show-overflow-tooltip/>
                        <el-table-column label="Actions" min-width="120px">
                            <template #header>
                                <el-icon size="small" class="el-icon--left">
                                    <Tools/>
                                </el-icon>
                                Actions
                            </template>
                            <template #default="scope">
                                <ConfirmsPassword @confirmed="updateStatus(scope.row.id, scope.$index)">
                                    <el-button :type="scope.row.active? 'warning' : 'success'" size="small" class="mr-2">
                                        <el-icon class="el-icon--left">
                                            <CircleClose v-if="scope.row.active"/>
                                            <CircleCheck v-else/>
                                        </el-icon>
                                        {{ scope.row.active ? 'Deactivate' : 'Activate' }}
                                    </el-button>
                                </ConfirmsPassword>
                                <el-button @click="$go(route('licenses', {client: scope.row.id}))" type="info" v-if="scope.row.licenses_count > 0"
                                           size="small" class="ml-2"><el-icon class="el-icon--left"><Tickets/></el-icon>Licenses
                                </el-button>
                                <el-button v-if="scope.row.licenses_count < 1" @click="deleteProject(scope.row.id, scope.$index)" type="danger" size="small">
                                    <el-icon class="el-icon--left">
                                        <Delete/>
                                    </el-icon> Del
                                </el-button>
                            </template>
                        </el-table-column>
                    </el-table>
                </div>
            </div>
        </div>
    </AppLayout>
</template>

<script>
import AppLayout from "@/Layouts/AppLayout.vue";
import {Plus, Delete, Tools, Tickets, CircleCheck, CircleClose} from '@element-plus/icons-vue';
import {reactive, ref} from "vue";
import ConfirmsPassword from '@/Components/ConfirmsPassword.vue'

export default {
    name: "Client",
    components: {
        Plus, Delete, Tools, Tickets, CircleCheck, CircleClose,
        AppLayout, ConfirmsPassword
    },
    data() {
        return {
            projects: ref(this.$page.props.projects),
        }
    },
    methods: {
        updateStatus(project, index) {
            axios.post(route('projects.status', [project]))
                .then(res => res.data)
                .then(data => {
                    this.projects.splice(index, 1, data)
                })
        },
        deleteProject(project, index) {
            axios.post(route('projects.delete', [project]))
                .then(res => res.data)
                .then(data => {
                    this.projects.splice(index, 1)
                })
        }
    }
}
</script>

<style scoped>

</style>
